diff --git a/inventory/group_vars/osbs-aarch64-masters-stg b/inventory/group_vars/osbs-aarch64-masters-stg
new file mode 100644
index 0000000..2b1d641
--- /dev/null
+++ b/inventory/group_vars/osbs-aarch64-masters-stg
@@ -0,0 +1,159 @@
+---
+# Define resources for this group of hosts here.
+lvm_size: 60000
+mem_size: 8192
+num_cpus: 2
+
+tcp_ports: [ 80, 443, 8443]
+
+openshift_node_labels: {'region':'infra'}
+openshift_schedulable: False
+
+docker_cert_dir: "/etc/docker/certs.d/candidate-registry.stg.fedoraproject.org"
+source_registry: "registry.stg.fedoraproject.org"
+docker_registry: "candidate-registry.stg.fedoraproject.org"
+
+osbs_url: "osbs.stg.fedoraproject.org"
+
+koji_url: "koji.stg.fedoraproject.org"
+
+osbs_client_conf_path: /etc/osbs.conf
+
+osbs_namespace: "osbs-fedora"
+osbs_worker_namespace: worker
+
+osbs_worker_service_accounts:
+  - orchestrator
+  - builder
+
+
+osbs_conf_sources_command: fedpkg sources
+osbs_conf_vendor: Fedora Project
+
+osbs_orchestrator_cpu_limitrange: "95m"
+
+osbs_worker_default_nodeselector: "worker=true"
+osbs_orchestrator_default_nodeselector: "orchestrator=true"
+
+osbs_conf_service_accounts:
+  - koji
+  - builder
+
+osbs_conf_readwrite_users:
+  - "system:serviceaccount:{{ osbs_namespace }}:default"
+  - "system:serviceaccount:{{ osbs_namespace }}:builder"
+
+osbs_conf_worker_clusters:
+  aarch64:
+  - name: aarch64
+    max_concurrent_builds: 1
+    openshift_url: "https://osbs.stg.fedoraproject.org/"
+    verify_ssl: 'false'
+
+osbs_platform_descriptors:
+- platform: aarch64
+  architecture: aarch64
+  enable_v1: True
+
+_osbs_reactor_config_map:
+    version: 1
+
+    clusters:
+      aarch64:
+      - name: "aarch64"
+        max_concurrent_builds: 1
+
+    clusters_client_config_dir: "/var/run/secrets/atomic-reactor/client-config-secret"
+
+    koji:
+      hub_url: "https://koji{{ env_suffix }}.fedoraproject.org/kojihub"
+      root_url: "https://koji{{ env_suffix }}.fedoraproject.org/"
+      auth:
+        krb_principal: "osbs/{{osbs_url}}@{{ ipa_realm }}"
+        krb_keytab_path: "FILE:/etc/krb5.osbs_{{ osbs_url }}.keytab"
+
+    odcs:
+        api_url: "https://odcs{{ env_suffix }}.fedoraproject.org/api/1"
+        auth:
+          openidc_dir: "/var/run/secrets/atomic-reactor/odcs-oidc-secret"
+        signing_intents:
+          - name: unsigned
+            keys: []
+        default_signing_intent: "unsigned"
+
+    pdc:
+        api_url: "https://pdc{{ env_suffix }}.fedoraproject.org/rest_api/v1/"
+
+    image_labels:
+      vendor: "{{ osbs_conf_vendor }}"
+      authoritative-source-url: "{{ source_registry }}"
+      distribution-scope: public
+
+    image_equal_labels:
+      - ['description', 'io.k8s.description']
+    openshift:
+      url: "https://{{ osbs_url }}"
+      insecure: true
+      build_json_dir: /usr/share/osbs
+      auth:
+        enable: True
+
+    platform_descriptors: "{{ osbs_platform_descriptors }}"
+
+    prefer_schema1_digest: False
+
+    content_versions:
+    - v1
+    - v2
+
+    registries:
+    - url: https://candidate-registry.stg.fedoraproject.org/v2
+      insecure: False
+      auth:
+        cfg_path: /var/run/secrets/atomic-reactor/v2-registry-dockercfg
+
+    source_registry:
+      url: "{{ source_registry }}"
+      insecure: True
+
+    group_manifests: True
+
+    sources_command: "{{ osbs_conf_sources_command }}"
+
+    artifacts_allowed_domains: []
+    #- download.devel.redhat.com/released
+    #- download.devel.redhat.com/devel/candidates
+
+    required_secrets:
+    - v2-registry-dockercfg
+    - odcs-oidc-secret
+
+    worker_token_secrets:
+    - aarch64-orchestrator
+    - client-config-secret
+
+_osbs_scratch_reactor_config_map_overrides:
+  image_labels:
+    distribution-scope: private
+
+osbs_reactor_config_maps:
+- name: reactor-config-map
+  data: "{{ _osbs_reactor_config_map }}"
+- name: reactor-config-map-scratch
+  data: >
+    {{ _osbs_reactor_config_map |
+       combine(_osbs_scratch_reactor_config_map_overrides, recursive=True) }}
+
+osbs_odcs_enabled: true
+
+#Docker command delegated host
+composer: composer.stg.phx2.fedoraproject.org
+
+# Nagios configuration
+nagios_Check_Services:
+  nrpe: true
+  sshd: true
+  named: false
+  dhcpd: false
+  httpd: false
+  swap: false
diff --git a/inventory/group_vars/osbs-aarch64-nodes-stg b/inventory/group_vars/osbs-aarch64-nodes-stg
new file mode 100644
index 0000000..fd8002c
--- /dev/null
+++ b/inventory/group_vars/osbs-aarch64-nodes-stg
@@ -0,0 +1,17 @@
+---
+# Define resources for this group of hosts here.
+lvm_size: 60000
+mem_size: 8192
+num_cpus: 2
+
+tcp_ports: [ 80, 443, 8443, 10250]
+
+openshift_node_labels: {'region': 'primary', 'zone': 'default'}
+
+nagios_Check_Services:
+  nrpe: true
+  sshd: true
+  named: false
+  dhcpd: false
+  httpd: false
+  swap: false
diff --git a/inventory/group_vars/osbs-masters-stg b/inventory/group_vars/osbs-masters-stg
index 1af11ff..272ae70 100644
--- a/inventory/group_vars/osbs-masters-stg
+++ b/inventory/group_vars/osbs-masters-stg
@@ -50,7 +50,6 @@ osbs_conf_worker_clusters:
     openshift_url: "https://osbs.stg.fedoraproject.org/"
     verify_ssl: 'false'
 
-
 osbs_platform_descriptors:
 - platform: x86_64
   architecture: amd64
diff --git a/inventory/host_vars/osbs-aarch64-master01.stg.arm.fedoraproject.org b/inventory/host_vars/osbs-aarch64-master01.stg.arm.fedoraproject.org
new file mode 100644
index 0000000..9e8b6aa
--- /dev/null
+++ b/inventory/host_vars/osbs-aarch64-master01.stg.arm.fedoraproject.org
@@ -0,0 +1,19 @@
+---
+nm: 255.255.255.0
+gw: 10.5.129.254
+dns: 10.5.126.21
+ks_url: http://10.5.126.23/repo/rhel/ks/kvm-fedora-aarch64-28-osbs
+ks_repo: http://10.5.126.23/pub/fedora/linux/releases/28/Server/aarch64/os/
+volgroup: /dev/vg_Server
+eth0_ip: 10.5.129.30
+vmhost: aarch64-c23n1.arm.fedoraproject.org
+datacenter: phx2
+host_group: osbs-aarch64-masters-stg
+
+nrpe_procs_warn: 900
+nrpe_procs_crit: 1000
+
+lvm_size: 120g
+mem_size: 16384
+max_mem_size: 16384
+num_cpus: 4
diff --git a/inventory/host_vars/osbs-aarch64-node01.stg.arm.fedoraproject.org b/inventory/host_vars/osbs-aarch64-node01.stg.arm.fedoraproject.org
new file mode 100644
index 0000000..0c91343
--- /dev/null
+++ b/inventory/host_vars/osbs-aarch64-node01.stg.arm.fedoraproject.org
@@ -0,0 +1,19 @@
+---
+nm: 255.255.255.0
+gw: 10.5.129.254
+dns: 10.5.126.21
+ks_url: http://10.5.126.23/repo/rhel/ks/kvm-fedora-aarch64-28-osbs
+ks_repo: http://10.5.126.23/pub/fedora/linux/releases/28/Server/aarch64/os/
+volgroup: /dev/vg_Server
+eth0_ip: 10.5.129.31
+vmhost: aarch64-c24n1.arm.fedoraproject.org
+datacenter: phx2
+host_group: osbs-aarch64-nodes-stg
+
+nrpe_procs_warn: 900
+nrpe_procs_crit: 1000
+
+lvm_size: 120g
+mem_size: 16384
+max_mem_size: 16384
+num_cpus: 4
diff --git a/inventory/inventory b/inventory/inventory
index c86a45d..9d9fda1 100644
--- a/inventory/inventory
+++ b/inventory/inventory
@@ -817,6 +817,7 @@ osbs-control01.stg.phx2.fedoraproject.org
 osbs-master01.stg.phx2.fedoraproject.org
 osbs-node01.stg.phx2.fedoraproject.org
 osbs-node02.stg.phx2.fedoraproject.org
+osbs-aarch64-master01.stg.arm.fedoraproject.org
 packages03.stg.phx2.fedoraproject.org
 pdc-backend01.stg.phx2.fedoraproject.org
 pdc-backend02.stg.phx2.fedoraproject.org
@@ -1423,6 +1424,12 @@ osbs-masters
 [osbs-masters-stg]
 osbs-master01.stg.phx2.fedoraproject.org
 
+[osbs-aarch64-masters-stg]
+osbs-aarch64-master01.stg.arm.fedoraproject.org
+
+[osbs-aarch64-nodes-stg]
+osbs-aarch64-master01.stg.arm.fedoraproject.org
+
 [osbs-nodes-stg]
 osbs-node01.stg.phx2.fedoraproject.org
 osbs-node02.stg.phx2.fedoraproject.org
@@ -1431,6 +1438,8 @@ osbs-node02.stg.phx2.fedoraproject.org
 osbs-control-stg
 osbs-masters-stg
 osbs-nodes-stg
+osbs-aarch64-masters-stg
+osbs-aarch64-nodes-stg
 
 [os-control-stg]
 os-control01.stg.phx2.fedoraproject.org
